==> Evergreen-ILS-3.15.9.tar.gz: Evergreen-ILS-3.15.9/Open-ILS/web/js/dojo/openils/opac/nls/ru-ru/opac.js <==
{
    ":BARCODE_PROMPT": "\u0428\u0442\u0440\u0438\u0445-\u043a\u043e\u0434: ",
    ":USERNAME_PROMPT": "Username: ",
    ":CANCEL_BUTTON_LABEL": "\u041e\u0442\u043c\u0435\u043d\u0430",
    ":SUBMIT_BUTTON_LABEL": "\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "\u041e\u0442\u0432\u0435\u0442 \u0434\u043b\u044f \u0441\u0431\u0440\u043e\u0441\u0430 \u043f\u0430\u0440\u043e\u043b\u044f",
    ":PWD_RESET_SUBMIT_SUCCESS": "Your request to begin the password reset process has been processed. If your account has a valid email address, you should soon receive an email containing further instructions for resetting your password.",
    ":PWD_RESET_SUBMIT_ERROR": "\u0421\u0438\u0441\u0442\u0435\u043c\u0430 \u043d\u0435 \u043c\u043e\u0436\u0435\u0442 \u043e\u0431\u0440\u0430\u0431\u043e\u0442\u0430\u0442\u044c \u0412\u0430\u0448 \u0437\u0430\u043f\u0440\u043e\u0441 \u0434\u043b\u044f \u0441\u0431\u0440\u043e\u0441\u0430 \u043f\u0430\u0440\u043e\u043b\u044f. \u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u043f\u043e\u043f\u0440\u043e\u0431\u0443\u0439\u0442\u0435 \u0435\u0449\u0435 \u0440\u0430\u0437, \u0438\u043b\u0438 \u043e\u0431\u0440\u0430\u0442\u0438\u0442\u0435\u0441\u044c \u043a \u0410\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u0440\u0443 \u0437\u0430 \u043f\u043e\u043c\u043e\u0449\u044c\u044e.",
    ":PWD_RESET_SUBMIT_STATUS": "\u041e\u0442\u043f\u0440\u0430\u0432\u043a\u0430 \u0437\u0430\u043f\u0440\u043e\u0441\u0430 ...",
    ":PWD_RESET_FORGOT_PROMPT": "\u0417\u0430\u0431\u044b\u043b\u0438 \u043f\u0430\u0440\u043e\u043b\u044c?",
    ":PWD_RESET_FORM_TITLE": "\u0417\u0430\u043f\u0440\u043e\u0441 \u043f\u0430\u0440\u043e\u043b\u044f",
    ":PWD_RESET_SUBMIT_PROMPT": "To begin the password reset process, enter either your barcode or username in the form below and click 'Submit'",
    ":CREATE_MFHD": "\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c MFHD \u0437\u0430\u043f\u0438\u0441\u044c",
    ":CREATED_MFHD_RECORD": "\u0421\u043e\u0437\u0434\u0430\u043d\u043d\u0430\u044f MFHD \u0437\u0430\u043f\u0438\u0441\u044c \u0434\u043b\u044f ${0}",
    ":DELETE_MFHD": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0437\u0430\u043f\u0438\u0441\u044c",
    ":DELETE_MFHD_CONFIRM": "Are you sure you want to delete this serial record?",
    ":DELETED_MFHD_RECORD": "\u0423\u0434\u0430\u043b\u0451\u043d\u043d\u0430\u044f MFHD \u0437\u0430\u043f\u0438\u0441\u044c ${0}",
    ":EDIT_MFHD_RECORD": "\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0437\u0430\u043f\u0438\u0441\u044c",
    ":EDIT_MFHD_MENU": "\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043d\u044b\u0435",
    ":EDIT_PROPERTIES": "Edit Properties",
    ":BASIC_HOLDINGS": "\u041e\u0431\u044a\u0451\u043c\u044b",
    ":BASIC_HOLDINGS_ADD": "Additional Volume Information",
    ":INDEX_HOLDINGS": "Indexes",
    ":INDEX_HOLDINGS_ADD": "Additional Index Information",
    ":CURRENT_HOLDINGS": "\u0422\u0435\u043a\u0443\u0449\u0438\u0439 \u0442\u043e\u043c",
    ":CURRENT_INDEXES": "\u0422\u0435\u043a\u0443\u0449\u0438\u0435 \u0443\u043a\u0430\u0437\u0430\u0442\u0435\u043b\u0438",
    ":CURRENT_SUPPLEMENTS": "\u0422\u0435\u043a\u0443\u0449\u0438\u0435 \u0434\u043e\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f",
    ":HOLDINGS_TABLE_CAPTION": "\u041a\u0440\u0430\u0442\u043a\u043e\u0435 \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u043d\u0438\u0435  \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043d\u044b\u0445 (${0})",
    ":INCOMPLETE_VOLUMES": "\u041d\u0435\u043f\u043e\u043b\u043d\u044b\u0435 \u0442\u043e\u043c\u0430",
    ":MISSING_VOLUMES": "\u041e\u0442\u0441\u0443\u0442\u0441\u0442\u0432\u0443\u044e\u0449\u0438\u0435 \u0442\u043e\u043c\u0430",
    ":ONLINE_VOLUMES": "\u041e\u043d\u043b\u0430\u0439\u043d \u0442\u043e\u043c\u0430",
    ":SAVE_MFHD_LABEL": "\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c MFHD",
    ":SUPPLEMENT_HOLDINGS": "Supplements",
    ":SUPPLEMENT_HOLDINGS_ADD": "Additional Supplement Information",
    ":PLACE_HOLD": "Place hold",
    ":HOLD_STATUS_PLURAL": "hold # ${0} of ${1} total holds and ${2} potential items",
    ":HOLD_STATUS_SINGULAR": "hold # ${0} of ${1} total holds and ${2} potential item",
    ":MORE": "\u0415\u0449\u0451",
    ":MORE_COPIES_FULL_RECORD": "... more copies listed in full record",
    ":SOURCE_CANNOT_HAVE_COPIES": "Records from ${0} cannot have copies."
}

==> Evergreen-ILS-3.16.3.tar.gz: Evergreen-ILS-3.16.3/Open-ILS/web/js/dojo/openils/opac/nls/ru-ru/opac.js <==
{
    ":BARCODE_PROMPT": "\u0428\u0442\u0440\u0438\u0445-\u043a\u043e\u0434: ",
    ":USERNAME_PROMPT": "\u0418\u043c\u044f \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f: ",
    ":CANCEL_BUTTON_LABEL": "\u041e\u0442\u043c\u0435\u043d\u0430",
    ":SUBMIT_BUTTON_LABEL": "\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "\u041e\u0442\u0432\u0435\u0442 \u0434\u043b\u044f \u0441\u0431\u0440\u043e\u0441\u0430 \u043f\u0430\u0440\u043e\u043b\u044f",
    ":PWD_RESET_SUBMIT_SUCCESS": "Your request to begin the password reset process has been processed. If your account has a valid email address, you should soon receive an email containing further instructions for resetting your password.",
    ":PWD_RESET_SUBMIT_ERROR": "\u0421\u0438\u0441\u0442\u0435\u043c\u0430 \u043d\u0435 \u043c\u043e\u0436\u0435\u0442 \u043e\u0431\u0440\u0430\u0431\u043e\u0442\u0430\u0442\u044c \u0412\u0430\u0448 \u0437\u0430\u043f\u0440\u043e\u0441 \u0434\u043b\u044f \u0441\u0431\u0440\u043e\u0441\u0430 \u043f\u0430\u0440\u043e\u043b\u044f. \u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u043f\u043e\u043f\u0440\u043e\u0431\u0443\u0439\u0442\u0435 \u0435\u0449\u0435 \u0440\u0430\u0437, \u0438\u043b\u0438 \u043e\u0431\u0440\u0430\u0442\u0438\u0442\u0435\u0441\u044c \u043a \u0410\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u0440\u0443 \u0437\u0430 \u043f\u043e\u043c\u043e\u0449\u044c\u044e.",
    ":PWD_RESET_SUBMIT_STATUS": "\u041e\u0442\u043f\u0440\u0430\u0432\u043a\u0430 \u0437\u0430\u043f\u0440\u043e\u0441\u0430 ...",
    ":PWD_RESET_FORGOT_PROMPT": "\u0417\u0430\u0431\u044b\u043b\u0438 \u043f\u0430\u0440\u043e\u043b\u044c?",
    ":PWD_RESET_FORM_TITLE": "\u0417\u0430\u043f\u0440\u043e\u0441 \u043f\u0430\u0440\u043e\u043b\u044f",
    ":PWD_RESET_SUBMIT_PROMPT": "\u0427\u0442\u043e\u0431\u044b \u043d\u0430\u0447\u0430\u0442\u044c \u043f\u0440\u043e\u0446\u0435\u0441\u0441 \u0441\u0431\u0440\u043e\u0441\u0430 \u043f\u0430\u0440\u043e\u043b\u044f, \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \u043b\u0438\u0431\u043e \u0432\u0430\u0448 \u0448\u0442\u0440\u0438\u0445-\u043a\u043e\u0434 \u0438\u043b\u0438 \u0438\u043c\u044f \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f \u0432 \u0444\u043e\u0440\u043c\u0435 \u043d\u0438\u0436\u0435 \u0438 \u043d\u0430\u0436\u043c\u0438\u0442\u0435 \"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c\"",
    ":CREATE_MFHD": "\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c MFHD \u0437\u0430\u043f\u0438\u0441\u044c",
    ":CREATED_MFHD_RECORD": "\u0421\u043e\u0437\u0434\u0430\u043d\u043d\u0430\u044f MFHD \u0437\u0430\u043f\u0438\u0441\u044c \u0434\u043b\u044f ${0}",
    ":DELETE_MFHD": "\u0423\u0434\u0430\u043b\u0438\u0442\u044c \u0437\u0430\u043f\u0438\u0441\u044c",
    ":DELETE_MFHD_CONFIRM": "Are you sure you want to delete this serial record?",
    ":DELETED_MFHD_RECORD": "\u0423\u0434\u0430\u043b\u0451\u043d\u043d\u0430\u044f MFHD \u0437\u0430\u043f\u0438\u0441\u044c ${0}",
    ":EDIT_MFHD_RECORD": "\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0437\u0430\u043f\u0438\u0441\u044c",
    ":EDIT_MFHD_MENU": "\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043d\u044b\u0435",
    ":EDIT_PROPERTIES": "\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u0432\u043e\u0439\u0441\u0442\u0432\u0430",
    ":BASIC_HOLDINGS": "\u041e\u0431\u044a\u0451\u043c\u044b",
    ":BASIC_HOLDINGS_ADD": "Additional Volume Information",
    ":INDEX_HOLDINGS": "Indexes",
    ":INDEX_HOLDINGS_ADD": "Additional Index Information",
    ":CURRENT_HOLDINGS": "\u0422\u0435\u043a\u0443\u0449\u0438\u0439 \u0442\u043e\u043c",
    ":CURRENT_INDEXES": "\u0422\u0435\u043a\u0443\u0449\u0438\u0435 \u0443\u043a\u0430\u0437\u0430\u0442\u0435\u043b\u0438",
    ":CURRENT_SUPPLEMENTS": "\u0422\u0435\u043a\u0443\u0449\u0438\u0435 \u0434\u043e\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f",
    ":HOLDINGS_TABLE_CAPTION": "\u041a\u0440\u0430\u0442\u043a\u043e\u0435 \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u043d\u0438\u0435  \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043d\u044b\u0445 (${0})",
    ":INCOMPLETE_VOLUMES": "\u041d\u0435\u043f\u043e\u043b\u043d\u044b\u0435 \u0442\u043e\u043c\u0430",
    ":MISSING_VOLUMES": "\u041e\u0442\u0441\u0443\u0442\u0441\u0442\u0432\u0443\u044e\u0449\u0438\u0435 \u0442\u043e\u043c\u0430",
    ":ONLINE_VOLUMES": "\u041e\u043d\u043b\u0430\u0439\u043d \u0442\u043e\u043c\u0430",
    ":SAVE_MFHD_LABEL": "\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c MFHD",
    ":SUPPLEMENT_HOLDINGS": "Supplements",
    ":SUPPLEMENT_HOLDINGS_ADD": "Additional Supplement Information",
    ":PLACE_HOLD": "Place hold",
    ":HOLD_STATUS_PLURAL": "hold # ${0} of ${1} total holds and ${2} potential items",
    ":HOLD_STATUS_SINGULAR": "hold # ${0} of ${1} total holds and ${2} potential item",
    ":MORE": "\u0415\u0449\u0451",
    ":MORE_COPIES_FULL_RECORD": "... more copies listed in full record",
    ":SOURCE_CANNOT_HAVE_COPIES": "Records from ${0} cannot have copies."
}
